<?php
/** Khowar (کھوار)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Rachitrali
 */

$fallback = 'ur';
$rtl = true;

$messages = array(
# User preference toggles
'tog-underline' => 'ربطو خط کشیدگی',
'tog-justify' => 'خطان  برابری',
'tog-hideminor' => 'موجودہ وختہ بیرو تبدیلیان موژار معمولی ترمیماتن کھوشتاؤے',
'tog-hidepatrolled' => 'موجودہ وختہ بیرو تبدیلیان موژار گشتی ترمیماتن کھوشتاؤے',
'tog-newpageshidepatrolled' => 'جدید صفحاتی فہرستہ گشتی صفحاتن کھوشاوے',
'tog-extendwatchlist' => 'زیرِنظرفہرستو پھیلاؤ  کورے تاکہ ھیارا تھمامو ترمیمات غیچھی گیانی، نہ کہ صرفی تازہ ترین',
'tog-usenewrc' => 'افزودہ حالیہ تبدیلیان استعمال کورے (JavaScript ضرورت بوی)',
'tog-numberheadings' => 'سرخیانتے تان لمبار دیت',
'tog-showtoolbar' => 'تدوینی اوزاردانن پشاؤے ( JavaScript ضرورت بوی)',
'tog-editondblclick' => 'کلکہ صفحاتن  ترمیم (JavaScript ضرورت بوی)',
'tog-editsection' => '[ترمیم] روابطان ذریعا سطری ترمیم کاریو فعال کورے',
'tog-editsectiononrightclick' => 'سطری عنواناتا فروسکی کلکو ذریعا سطری ترمیم کاریو فعال ساؤزاوے',
'tog-showtoc' => 'فہرستِ مندرجات پشاؤے (3 زیات سرخی والا صفحاتن بچے)',
'tog-rememberpassword' => 'ھیہ کمپیوٹرا مہ داخل کاردو معلوماتن یاد لاکھے(کم از کم $1 {{PLURAL:$1|بس|بس}})',
'tog-watchcreations' => 'مہ مرتب کاردو صفحاتن مہ  زیرِنظرفہرستہ شامل کورے',
'tog-watchdefault' => 'مہ ترمیم کاردو صفحاتن مہ  زیرِنظرفہرستہ شامل کورے',
'tog-watchmoves' => 'آوا کیہ صفحاتن کہ منتقل کومان ھتیتان مہ زیرِنظرفہرستہ شامل کورے',
'tog-watchdeletion' => 'آوا کیہ صفحاتن کہ حذف آریتام، ھتیتان مہ زیرِنظرفہرستہ شامل کورے',
'tog-minordefault' => 'تھمامو ترمیماتن ہمیشہ بطورِ معمولی ترمیم نشانزد کورے',
'tog-previewontop' => 'تدوینی خاناری پروشٹی نمائش پشاؤے',
'tog-previewonfirst' => 'آویلو ترمیما نمائش پشاؤے',
'tog-nocache' => 'بطن کاری صفحہو غیر فعال ساؤزاوے',
'tog-enotifwatchlistpages' => 'کیاوتکہ مہ  زیرِنظرفہرستہو کیہ صفحہا تبدیلی واقع کہ ہوی تھے متے بشلی کغاز انزاوے',
'tog-enotifusertalkpages' => 'کیاوتکہ مہ تبادلۂ خیالو صفحہ تبدیلی واقع کہ ہویی تھے متے بشلی کغاز(ای میل) انځاوے جما',
'tog-enotifminoredits' => 'صفحاتہ معمولی ترمیماتن بارا دی متے بشلی کغاز انزاوے',
'tog-enotifrevealaddr' => 'خبرداری بشلی کغازا مہ ای میل پتو ظاہر کورے',
'tog-shownumberswatching' => 'لوڑاک ممبرانن تعدادان پشاؤے',
'tog-oldsig' => 'موجودہ دستخطو نمائش:',
'tog-fancysig' => '(سادہ دسخط بلا خودکار ربط)',
'tog-uselivepreview' => 'براہِ راست نمائش استعمال کورے (JavaScript ضرورت بوی)',
'tog-forceeditsummary' => 'کیاوتکی آوا ترمیمی خلاصو خالی پیڅھیتام تھے متے لو دیت',
'tog-watchlisthideown' => 'زیرِنظرفہرستہ مہ ترمیماتن کھوشاوے',
'tog-watchlisthidebots' => 'زیرِنظرفہرستہ مہ روبالی ترمیماتن کھوشتاوے',
'tog-watchlisthideminor' => 'زیرِنظرفہرستاری معمولی ترمیماتن کھوشتاوے',
'tog-watchlisthideliu' => 'زیرِنظرفہرستاری داخلِ نوشتہ شدہ صارفینان ترمیماتن کھوشتاوے',
'tog-watchlisthideanons' => 'زیرِنظرفہرستاری نامعلوم صارفینان ترمیماتن کھوشتاوے',
'tog-watchlisthidepatrolled' => 'زیرِنظرفہرستاری گشت شدہ ترمیماتن کھوشتاوے',
'tog-ccmeonemails' => 'دیگر ممبراننتے ارسال کاردو بشلی کغازان نقلان متے انزاوے',
'tog-diffonly' => 'مختلفاتن موڑا صفحو مشمولاتن مو پشاوے',
'tog-showhiddencats' => 'پوشیدہ(کھوشت) زمرہ جاتن پشاوے',

'underline-always' => 'ہمیش',
'underline-never' => 'کیاوت دی نو',
'underline-default' => 'براوزرو طے شدہ',

# Font style option in Special:Preferences
'editfont-style' => 'خانۂ تدوینو اندازِ تحریر:',
'editfont-default' => 'ڈیفالٹ براوزر',
'editfont-monospace' => 'یکفضائی نویسہ',
'editfont-sansserif' => 'بےحلیہ فونٹ',
'editfont-serif' => 'حلیہ فونٹ',

# Dates
'sunday' => 'یک شمبے',
'monday' => 'دو شمبے',
'tuesday' => 'سہ شمبے',
'wednesday' => 'چار شمبے',
'thursday' => 'پنج شمبے',
'friday' => 'آدینہ',
'saturday' => 'شمبے',
'sun' => 'یک شمبے',
'mon' => 'دو شمبے',
'tue' => 'سے شمبے',
'wed' => 'چار شمبے',
'thu' => 'پنچ شمبے',
'fri' => 'آدینہ',
'sat' => 'شمبے',
'january' => 'جنوری',
'february' => 'فروری',
'march' => 'مارچ',
'april' => 'اپريل',
'may_long' => 'مئی',
'june' => 'جون',
'july' => 'جولائی',
'august' => 'اگست',
'september' => 'ستمبر',
'october' => 'اکتوبر',
'november' => 'نومبر',
'december' => 'دسمبر',
'january-gen' => 'جنوری',
'february-gen' => 'فروری',
'march-gen' => 'مارچ',
'april-gen' => 'اپریل',
'may-gen' => 'مئی',
'june-gen' => 'جون',
'july-gen' => 'جولائی',
'august-gen' => 'اگست',
'september-gen' => 'ستمبار',
'october-gen' => 'اکتوبار',
'november-gen' => 'نومبار',
'december-gen' => 'دسمبار',
'jan' => 'جنوری',
'feb' => 'فروری',
'mar' => 'مارچ',
'apr' => 'اپریل',
'may' => 'مئی',
'jun' => 'جون',
'jul' => 'جولائی',
'aug' => 'اگست',
'sep' => 'ستمبر',
'oct' => 'اکتوبر',
'nov' => 'نومبر',
'dec' => 'دسمبر',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|زمرہ|زمرہ جات}}',
'category_header' => 'زمرہ "$1" مضمون\'',
'subcategories' => 'ذیلی ذمرہ جات',
'category-media-header' => 'زمرا "$1" میڈیا',
'category-empty' => '‘‘ھیہ زمرا ھنیسے کیہ صفحہ یا میڈیا موجود نیکی.’’',
'hidden-categories' => '{{PLURAL:$1|کھوشت زمرہ|کھوشت زمرہ جات}}',
'hidden-category-category' => 'کھوشت زمرہ جات',
'category-subcat-count' => '{{PLURAL:$2|اِس زمرہ میں صرف درج ذیل ذیلی زمرہ ہے.|اِس زمرہ میں درج ذیل {{PLURAL:$1|ذیلی زمرہ|$1 ذیلی زمرہ جات}}, کل $2 میں سے.}}',
'category-subcat-count-limited' => 'ھیہ زمرا درج ذیل {{PLURAL:$1|ذیلی زمرہ ہے|$1 ذیلی زمرہ جات شینی}}.',
'category-article-count' => '{{Plural:$2|مضمون شینی|{{Plural:$1|صفحا|صفحا}} $2 ھیہ زمرا مضمون شینی}}',
'category-article-count-limited' => 'The following {{PLURAL:$1|صفحا|$1 صفحات}} in the current category.',
'category-file-count' => '{{Plural:$2|مضمون شینی|{{Plural:$1|صفحا|صفحا}} $2 ھیہ زمرا مضمون شینی}}',
'category-file-count-limited' => 'The following {{PLURAL:$1|file is|$1 files are}} in the current category.',
'listingcontinuesabbrev' => 'جاری',
'index-category' => 'نو انڈیکس صفحات',
'noindex-category' => 'نو انڈیکس صفحات',
'broken-file-category' => 'نس پھت صفحات',
'categoryviewer-pagedlinks' => '($1) ($2)',

'about' => 'تعارف',
'article' => 'صفحۂ مشمول',
'newwindow' => 'نوغ کھیڑکیا',
'cancel' => 'کھینسل',
'moredotdotdot' => 'وا...',
'mypage' => 'مہ صفحہ',
'mytalk' => 'مہ مشقولگی',
'anontalk' => 'بچے لو IP ھیہ',
'navigation' => 'رہنمائی',
'and' => '&#32;وا',

# Cologne Blue skin
'qbfind' => 'تلاش کورے',
'qbbrowse' => 'Browse/تصفّح',
'qbedit' => 'ترمیم',
'qbpageoptions' => 'ھیہ صفحہ',
'qbmyoptions' => 'مہ صفحات',
'qbspecialpages' => 'خاص صفحات',
'faq' => 'عام معلومات',
'faqpage' => 'Project:معلوماتِ عامہ',

# Vector skin
'vector-action-addsection' => 'نوغ موضوع',
'vector-action-delete' => 'بوغاوے',
'vector-action-move' => 'منتقل کورے',
'vector-action-protect' => 'محفوظ کورے',
'vector-action-undelete' => 'اچی انگیے',
'vector-action-unprotect' => 'غیر محفوظ',
'vector-view-create' => 'ساوزاوے',
'vector-view-edit' => 'ایڈٹ کورے',
'vector-view-history' => 'تاریخچہ',
'vector-view-view' => 'راوے',
'vector-view-viewsource' => 'مسودہ',
'actions' => 'ایکشنز',
'namespaces' => 'نامان ژاغہ',
'variants' => 'الگ',

'errorpagetitle' => 'خطاء',
'returnto' => 'آچی $1۔',
'tagline' => '{{SITENAME}}ری',
'help' => 'مدد',
'search' => 'تلاش',
'searchbutton' => 'تلاش کورے',
'go' => 'Go/بوغے',
'searcharticle' => 'Go/بوغے',
'history' => 'تاریخچہ ء صفحہ',
'history_short' => 'تاریخچہ',
'printableversion' => 'قابل طبع نسخہ',
'permalink' => 'مستقل لنک',
'print' => 'طباعت',
'view' => 'لوڑے',
'edit' => 'ترمیم',
'create' => 'ساوزاوے',
'editthispage' => 'ھی صفحہا ترمیم کورے',
'create-this-page' => 'ھیہ صفحو ساوزاوے',
'delete' => 'بوغاوے',
'deletethispage' => 'ھیہ صفحہو بوغاوے',
'undelete_short' => 'بحال {{PLURAL:$1|ای ترمیم|$1 ترامیم}}',
'protect' => 'محفوظ',
'protect_change' => 'تبدیل کورے',
'protectthispage' => 'ھیہ صفحو محفوظ کورے',
'unprotect' => 'غیر محفوظ',
'unprotectthispage' => 'ھیہ صفحہو غیر محفوظ کورے',
'newpage' => 'نوغ صفحہ',
'talkpage' => 'ھیہ صفحہا تبادلۂ خیال کورے',
'talkpagelinktext' => 'مشقولگی',
'specialpage' => 'خصوصی صفحہ',
'personaltools' => 'ذاتی سماند',
'postcomment' => 'پروشٹیو حصّہ',
'articlepage' => 'مندرجاتی صفحہو لوڑے',
'talk' => 'تبادلہٴ خیال',
'views' => 'خیالات',
'toolbox' => 'ٹول بکس',
'userpage' => 'یوزرو صفحو لوڑے',
'projectpage' => 'کھوار منصوبو صفحہو لوڑے',
'imagepage' => 'ھوٹوو صفحو لوڑے',
'mediawikipage' => 'پیغامو صفحہو لوڑے',
'templatepage' => 'سانچو صفحہو لوڑے',
'viewhelppage' => 'مددو صفحہو لوڑے',
'categorypage' => 'زمرہ‌جاتی صفحہو لوڑے',
'viewtalkpage' => 'تبادلۂ خیالو صفحہو لوڑے',
'otherlanguages' => 'خور زبانا',
'redirectedfrom' => "'($1 خور ژاغار گنونو ھوی)',",
'redirectpagesub' => 'ھیہ صفحو خور ژاغا آلونو بیتی شیر',
'lastmodifiedat' => 'آخری بار تدوین $2, $1 کورونو ھوی',
'viewcount' => 'ھیہ صفحہ گیونو ھوی {{PLURAL:$1|ای‌بار|$1 مرتبہ}}',
'protectedpage' => 'محفوظ شدہ صفحہ',
'jumpto' => 'ھیہ ووشکی څروٹھاوے',
'jumptonavigation' => 'رہنمائی',
'jumptosearch' => 'تلاش',
'view-pool-error' => 'معذرت: تمام سرورا موجودہ وختہ اِضافی بوجھ شیر.
بو زیادہ صارفین موجودہ وختہ ھیہ صفحو لاڑینیان 
برائے مہربانی! صفحو لوڑیکو بچے دوبارہ کوشش کوریکاری پروشٹی پھوکرو انتظار کورے.

$1',
'pool-errorunknown' => 'نامعلوم خطا',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'تعارف {{SITENAME}}',
'aboutpage' => 'Project:کھوار ویکیپیڈیو تعارف',
'copyright' => 'تمام مواد $1 تحتہ میانسار شیر',
'copyrightpage' => '{{ns:project}}:حقوق تصانیف',
'currentevents' => 'ھنونو واقعات',
'currentevents-url' => 'Project:ھنونو واقعات',
'disclaimers' => 'اعلانات',
'disclaimerpage' => 'Project:عام کھوار اعلان',
'edithelp' => 'مدد براۓ ترمیم',
'helppage' => 'Help:فھرست',
'mainpage' => 'آویلو صفحہ',
'mainpage-description' => 'سرورق',
'policy-url' => 'Project:حکمتِ عملی',
'portal' => 'مھراکہ',
'portal-url' => 'Project:مھراکہ',
'privacy' => 'رازان فاش نو کوریکو بچے اصول',
'privacypage' => 'Project:رازان فاش نو کوریکو بچے اصول',

'badaccess' => 'خطائے اجازت',
'badaccess-group0' => 'تو ھیہ کورمو کوریکو مُجاز نو',
'badaccess-groups' => 'تہ درخاس کاردو عمل {{PLURAL:$2|گروہ|گروہان موژار ای}}: $1 ممبارا پت محدود شیر',

'versionrequired' => 'میڈیا ویکیو $1 نسخہو لازمی ضرورت شیر',
'versionrequiredtext' => 'ھیہ صفحہو استعمال کوریکو بچے میڈیاویکیو $1 نسخہو ضرورت شیر.

[[Special:Version|version page]]',

'ok' => 'ٹھیک شیر',
'pagetitle' => '$1 - {{SITENAME}}',
'pagetitle-view-mainpage' => '{{SITENAME}}',
'retrievedfrom' => '‘‘$1’’ نقل کاردو',
'youhavenewmessages' => 'تہ بچے ای $1 شیر۔ ($2)',
'newmessageslink' => 'نوغ پیغامات',
'newmessagesdifflink' => 'تـجـدیـد مـاقـبل آخـراری فـرق',
'youhavenewmessagesmulti' => 'ء$1 تہ بچے نوغ نوغ پیغامات شینی',
'editsection' => 'ترمیم',
'editold' => 'ترمیم',
'viewsourceold' => 'مآخذو لوڑے',
'editlink' => 'تدوین کورے',
'viewsourcelink' => 'مآخذو لوڑے',
'editsectionhint' => 'تدوینِو حصّہ: $1',
'toc' => 'فہرست',
'showtoc' => 'پشاوے',
'hidetoc' => 'کھوشتاوے',
'collapsible-collapse' => 'خاتمہ/Collapse',
'collapsible-expand' => 'فراخ کورے',
'thisisdeleted' => 'لوڑے  یا بحال کورے $1',
'viewdeleted' => 'لوڑے $1؟',
'restorelink' => '{{PLURAL:$1|ای ترمیم حذف ہوی|$1 ترامیم حذف ہونی}}',
'site-rss-feed' => '$1 آر.ایس.ایس فیڈ',
'site-atom-feed' => '$1 اٹوم فیڈ',
'page-rss-feed' => '$1 آر ایس ایس فیڈ',
'page-atom-feed' => '$1 آٹوم فیڈ',
'feed-atom' => 'اٹوم',
'feed-rss' => 'آر ایس ایس',
'red-link-title' => '
$1 (صفحہ موجود نیکی)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'صفحہ',
'nstab-user' => 'یوزرو صفحہ',
'nstab-media' => 'صفحۂ میڈیا',
'nstab-special' => 'خاص صفحہ',
'nstab-project' => 'صفحۂ کھوار منصوبہ',
'nstab-image' => 'مسل',
'nstab-mediawiki' => 'پیغام',
'nstab-template' => 'سانچہ',
'nstab-help' => 'مدد',
'nstab-category' => 'زمرہ',

# Main script and global functions
'nosuchaction' => 'کیہ دی عمل نیکی',
'nosuchactiontext' => 'URL ووشکیاری مختص کاردو عمل درست نو.
تہ URL غلط نیویشیتاو، یا کیہ غیر صحیح ربطو پیرویو کوری آسوس.
{{ھموش نامہ SITENAME زیرِ استعمال مصنع لطیفا چاریو نشاندہیو دی اندیشہ شیر}}.',
'nosuchspecialpage' => 'کیہ ہش خاص صفحہ نیکی',
'nospecialpagetext' => "\"<big>'''تو ای ناقص خاص صفحہو بچے درخاس کوری آسوس.'''</big>

{{درست خاص صفحاتن ای فھرست  [[Special:SpecialPages|{{int:specialpages}}]]  لوڑیکو بوس}}.\"",

# General errors
'error' => 'Error/خطاء',
'databaseerror' => 'خطائے ڈیٹابیس',
'laggedslavemode' => 'Warning: Page may not contain recent updates.
خبردار: منکھن شیر کہ صفحہا موجودہ بتاریخہ جات شامل نو بونی',
'readonly' => 'ڈیٹابیسا قلف لیگی شیر',
'enterlockreason' => 'قلفو بچے کیہ وجہ درج کورے، بشمولِ تخمینہ کہ قلفو کیاوت کھولاو کورونو بوئے',
'readonlytext' => 'ڈیٹابیس  شاید معمولو اصلاحو بچے نوغ اندراجاتن اوچے خور ترمیماتن بچے قلف کورونو بیتی شیر ھیغار آچی ھیہ عام حالتہ گوی.
منتظم، کا کہ قلف لیگیے آسور، ھیہ تفصیلو فراہم کوری آسور: $1',
'missing-article' => '\'ڈیٹابیس کیہ صفحہو متنو بنام "$1" $2  نو لیتائے کھیو کہ ھو لیلک اوشوئے.

ھیہ عموماً کیہ صفحہو تاریخی یا پرانو حذف شدہ ربطو وجہو سورا دی بوئے. 

اگر ھیہ وجہ نو، تھے تہ مصنع‌لطیفا چاری داخل بیتی آسور.
برائے مہربانی، URL ھو نشان دیتی کیہ  
[[Special:ListUsers/sysop|منتظمو]] سوم ھے بارا کھوارا کغاز نیویشے.\',',
'missingarticle-rev' => '(نظرثانی#: $1)',
'missingarticle-diff' => '(مختلفات: $1, $2)',
'readonly_lag' => 'ڈیٹابیس خودکار طورا قلف کورونو بیتی شیر تاکہ ماتحت ڈیٹابیسی معیلاتن درجہ آقو بوئے',
'internalerror' => 'خطائے اندرونی',
'internalerror_info' => 'خطائے اندرونی: $1',
'filecopyerror' => '"$1" مسلو "$2" نقل کورونو نو ھوی',
'filerenameerror' => 'مسلو "$1" و "$2" خور نم دیونو نو ھوی',
'filedeleteerror' => 'مسلو "$1" حذف کورونو نو ھوی',
'directorycreateerror' => 'رہنامچہ "$1" تخلیق کورونو نو ھوی',
'filenotfound' => 'مسلو "$1" تلاش کورونو نو ھوی',
'fileexistserror' => 'مسلو "$1" نیویشکا قاصر، مسل موجود',
'unexpected' => 'غیرمتوقع قدر: "$1"="$2"',
'formerror' => 'خطا: کغاز انځینو نو ھوی',
'badarticleerror' => 'ھیہ صفحہا ھیہ عمل انجام دیونو نو ھوی۔',
'cannotdelete' => 'صفحہو $1 ڈیلیٹ کورونو نو ھوی۔ (ھیہ منکھن شیر کہ ھمو پروشٹی تان کا ڈیلیٹ کوری آسور۔)',
'badtitle' => 'خراب عنوان',
'badtitletext' => "'درخاس شدہ صفحہو عنوان ناقص، خالی، یا کیہ غلط ربط شدہ بین لسانی یا بین ویکی عنوان شیر.
شاید ھیارا ای یا زیات ھش حروف موجود شینی کہ ھیت عنوانا استعمال نو بونیان.',",
'perfcached' => 'ذیلی ڈیٹا ابطن شدہ شیر وا ھمو بیکا امکان شیر A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
'perfcachedts' => 'ذیلی ڈیٹا ابطن شدہ شیر وا آخری بار ھمو بتاریخیت $1 کورونو ہوئے. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.',
'querypage-no-updates' => 'ھیہ صفحہو بچے بتاریخات فی الحال ناقابل ساوزینو بیتی شینی. 
ھمو ڈیٹا ھنیسے تازہ کورونو نو بوئے',
'viewsource' => 'مسودو لوڑے',
'actionthrottledtext' => 'بطورِ ای ضدسپم تدبیر، تہ مختصار وختہ کئی دفعہ ھیہ کورومو کوریکو وجھین محدود کورونو ہوئے، وا تو ھیہ حدو پار کوری آسوس.
براہِ کرم، ای کما میلیٹ آچہ کھوشش کورے',
'protectedpagetext' => 'ھیہ صفحہو تدویناری محفوظ لاکھیکو بچے قلف لیگینو بیتی شیر',
'viewsourcetext' => 'تو صرف مضمونو لوڑیکو بوس وا ھو نقل کوریکو بوس:',
'protectedinterface' => 'ھیہ صفحہ مصنع‌لطیفو بچے سطح‌البینی متن فراہم کورویان، وا  ناجائزاستعمالو سدِبابو بچے ھمو قلف لیگینو بیتی شیر',
'editinginterface' => "\"'''خبردار:''' تو ای ھش صفحہو تدوینو کوروسان کہ ھیہ مصنع‌لطیفو بچے سطح‌البینی متن فراہم کورویان۔ ھیہ صفحہا کاردو ترمیم، دیگر ممبارانن بچے سطح‌البینو تبدیل کوروی۔
براہِ کرم، ترجمہ کوریکو بچے  [//translatewiki.net/wiki/Main_Page?setlang=en '''بیٹاویکی'''] (میڈیاویکی مقامیانی منصوبو) استعمال کورے.\",",
'namespaceprotected' => "\"تتے '''\$1''' فضائے نامہ صفحاتن تدوینو کوریکو اِجازت نیکی.\",",
'ns-specialprotected' => 'خاص صفحاتن تدوین کوریکو اجازت نیکی',
'titleprotected' => 'ھیہ عنوانو [[User:$1|$1]] تخلیق کوریکاری محفوظ کوری آسور.
وجہ ھیہ شیر: "\'\'$2\'\'"',

# Virus scanner
'virus-badscanner' => "\"خراب وضعیت: نوژان وائرسی مفراس: ''\$1''\",",
'virus-scanfailed' => 'تفریس ناکام (رمز $1)',
'virus-unknownscanner' => 'نوژان ضد وائرس:',

# Login and logout pages
'logouttext' => "'''ھنیسے تو خارج بیتی آسوس'''<br />
تو خفی الاسم {{SITENAME}}  استعمال جاری لاکھیکو بوس، یا دوبارہ ھیہ نامو یا مختلف نامان سورا داخل دی بیکو بوس۔  ھیہ یاد آوری کورے کہ ای کما صفحات ھش <span class='plainlinks'>[\$1 دوباری لاگن بوس]</span> غیچھی گونی کہ تو ھنیسے خارج نو بیتی آسوس، کلہ پت کہ تو تان تفصحہ (براؤزرو) ابطن (cache) صاف نوکوروس۔\",",
'yourname' => 'اسمِ رکنیت',
'yourpassword' => 'کلمۂ شناخت(پاسورڈ)',
'yourpasswordagain' => 'کلمۂ شناخت(پاسورڈو)دوبارہ نیویشے',
'remembermypassword' => 'ھیہ براوزیرا مہ داخلِ نوشتگی معلوماتن یاد لاکھے (زیاتاری زیات $1 {{PLURAL:$1|بس|بسان}} بچے)',
'yourdomainname' => 'تہ ڈومین',
'externaldberror' => 'یا تھے توثیقی ڈیٹابیسا خطا واقع بیتی شیر یا تتے بیریو کھاتو بتاریخ کوریکو اِجازت نیکی',
'login' => 'داخل بوس',
'nav-login-createaccount' => 'کھاتہ کھولاو کورے یا اندراج کورے',
'loginprompt' => '{{SITENAME}} کھوار ویکیپیڈیا داخلو بچے تہ سوم پاسورڈ بیک ضروری شیر',
'userlogin' => 'کھاتہ ساوزاوے یا اندراج کورے',
'userloginnocreate' => 'داخل نوشتہ بوس',
'logout' => 'لاگ آوٹ',
'userlogout' => 'لاگ آوٹ',
'notloggedin' => 'داخلہ نو ہوی',
'nologin' => 'تو کھاتہ نو ساوزے آسوسا؟ $1',
'nologinlink' => 'کھاتہ ساوزاوے',
'createaccount' => 'کھاتہ کھولاو کورے',
'gotaccount' => "پروشٹی تان کھاتا ساوزینو بیتی شیر؟'''$1'''.",
'gotaccountlink' => 'لاگن بوس',
'userlogin-resetlink' => 'آوا داخل بیکو بچے تان تفصیلاتن روخڅی اسوم',
'createaccountmail' => 'بذریعۂ بشلی ڈاک',
'createaccountreason' => 'وجہ:',
'badretype' => 'درج شدہ کلمۂ شناخت اصلو مطابقت نو لاکھویان',
'userexists' => 'تو کہ نامو کہ درج کوری آسوس ھیس پروشٹیاری استعمالہ شیر۔ مختلف نام استعمال کورے',
'loginerror' => 'داخلا غلطی',
'createaccounterror' => 'کھاتہ $1 ساوزینو نو بویان',
'noname' => 'تو تان صحیح اسم صارفو داخل نو آرو',
'loginsuccesstitle' => 'داخلہ کامیاب',
'loginsuccess' => "'''ھانیسے تو {{SITENAME}} بنام \"\$1\" داخل بیتی آسوس'''",
'nosuchuser' => '"$1" نامو سورا کیہ صارف موجود نیکی.
برائے مہربانی! ہجان درست اندراجان تصدیقو کورے.
اگر تو کہ مناسب جوشیتاو تھے [[Special:UserLogin/signup|نوغ کھاتہ دی ساوزیکو بوس]].',
'nouserspecified' => 'تہ ای اسمِ صارفو مخصوص کوریلک',
'login-userblocked' => 'ھیہ صارفو سورا پاوبندی شیر. داخلِ نوشتہ بیکو اجازت نیکی',
'wrongpassword' => 'تو غلط کلمۂ شناخت درج کوری آسوس دوبارہ کو شش کورے',
'wrongpasswordempty' => 'کلمۂ شناخت ندارد۔ دوبارہ کوشش کورے',
'passwordtooshort' => 'تہ منتخب کردہ پارلوظ(پاسورڈ) مختصار شیر. پارلوظ کم از کم {{PLURAL:$1|1 حرف|$1 حروف}} بیلک.',
'password-name-match' => 'تہ پارلوظ(پاسورڈ) تہ اسمِ صارفو ساری مختلف بیلک.',
'mailmypassword' => 'نوغ پاسورڈ بشلی کغازو زریعا انځاوے',
'passwordremindertitle' => 'نوغ عارضی کلمۂ شناخت برائے {{SITENAME}}',
'passwordremindertext' => '(IP پتاری $1) کا (یا البت تو) {{SITENAME}} ($4) 
بچے نوغ کلمۂ شناختو بچے درخاس آریر. ای عارضی کلمۂ شناخت "$3" 
برائے ممبار(صارف) "$2" تخلیق کورونو بیتی شیر. اگر ھیہ تہ ارادہ کہ اوشوی تھے تو داخلِ نوشتہ بیکار آچی نوغ کلمۂ شناختو انتخابو کورے.
تہ کلمۂ شناخت {{PLURAL:$5|ای بس|$5 بسار}} آچی ناکارہ بوی.

اگر خور کا ھیہ درخاسو کوری آسور، یا تتے تہ پرانو کلمۂ شناخت یادی گیتی شیر،
وا تو ھو تبدیل کوریک نو مشکیسان ،تھے تو ھیہ پیغامو نظر انداز کوریکو بوس وا تان پرانو کلمۂ شناختو استعمالو جاری لاکھیکو بوس.\',',
'noemail' => 'ممبارو "$1" بچے کیہ بشلی کغازو  پتہ درج کورونو نو بیتی شیر',
'noemailcreate' => 'صحیح برقی پتہ مہیّا کورے',
'passwordsent' => 'ای نوغ کلمۂ شناخت "$1" نامو سورا ساوز بیرو  بشلی کغازو پتہوتے انزینو بیتی شیر۔ 
کیاوتکہ ھسے توریتای تھے مہربانی کوری ھو ذریعا دوبارہ داخل بوس۔',
'blocked-mailpassword' => 'تہ  آئی.پی پتہو تدوین کوریکار  روکاو کورونو بیتی شیر، تھے، ناجائز استعمالو روکاو کوریکو بچے ، تہ آئی.پی پتہو کلمۂ شناختو بحالیو فعل استعمال کوریکو اِجازت نیکی',
'eauthentsent' => 'ای تصدیقی برقی خط نامزد کورونو بیرو برقی پتا کوری انځینو بیتی شیر.
تہ سوم توریرو برقی خطہ دیرو ہدایاتن سورا عمل کوری تو ھیہ لوو توثیق/تصدیقو کورے کہ مذکورہ برقی پتہ تہ زاتی پتہ شیر.',
'throttled-mailpassword' => 'گزشتہ {{PLURAL:$1|گھنٹہ|$1 گھنٹہ}}ان اندرینی پروشٹیار یری تان پارلوظو(پاسورڈو)ای یادآوری انځینو بیتی شیر.
ناجائز استعمالو سدّبابو بچے، {{PLURAL:$1|گھنٹہ|$1 گھنٹہ}}ان دورانی صرف ای پارلفظی یادآواری انځینو بوی',
'mailerror' => 'کغاز انزیکو دورانی مسلہ:$1',
'acct_creation_throttle_hit' => 'تہ آئی.پی پتو ذریعا ھیہ ویکیا گیاک صارفین شوخڅیرو ای بسہ{{PLURAL:$1|1 کھاتہ ساوزے آسور|$1 کھاتے ساوزے آسونی}}، وا ھیس مذکورہ وختہ کافی شیر.
لہٰذا، تہ آئی.پی پتو استعمال کوراک صارفین موجودہ وختہ مزید کھاتہ ساوزیکو نو بونی.',
'emailauthenticated' => 'تہ بشلی کغازو پتو تصدیق تاریخ $2 بوقت $3 بجا کورونو ھوی۔',
'emailnotauthenticated' => 'تہ برقی پتو ھنیسے  تصدیق نو بیتی شیر.
درج ذیل وجھو سورا کیہ دی اشناریو بچے تہ برقی پتہ کوری برقی ڈاک ارسال کورونو نو بوی.',
'noemailprefs' => 'ھمی خصائص یعنی فیچران کورما انگیکو بچے تان ترجیحاتہ برقی ڈاکو پتو متعین کورے.',
'emailconfirmlink' => 'تان برقی پتو تصدیقو کورے',
'accountcreated' => 'تخلیقِ کھاتہ',
'accountcreatedtext' => 'تخیلقِ کھاتۂ ممبار براۓ $1۔',
'createaccount-title' => 'کھاتہ سازی برائے {{SITENAME}}',
'usernamehasherror' => 'اسمِ صارفہ قیٹ پیٹ حروف استعمال کوریکو اجازت نیکی',
'login-throttled' => 'تو داخلِ نوشتہ بیکو بچے بو زیادہ کوششیں آرو.
دوبارہ کوشش کوریکو بچے پھوک مدا انتظار کورے.',
'loginlanguagelabel' => 'زبان: $1',

# Change password dialog
'resetpass' => 'پاسورڈو چینج کورے',
'resetpass_announce' => 'تو ای برقی ارسال کردہ عارضی کوڈ ورڈو سوم جستہ داخل بیتی آسوس.
داخلِ نوشتہ بیکو عملو مکمل کوریکو بچے تہ ھیارا نوغ پاسورڈ متعین کوریلک بوی:',
'resetpass_header' => 'کھاتو پاسورڈو تبدیل کورے',
'oldpassword' => 'پرانو کلمۂ شناخت:',
'newpassword' => 'نوغ کلمۂ شناخت',
'retypenew' => 'نوغ کلمۂ شناخت دوبارہ درج کورے:',
'resetpass_submit' => 'پاسورڈ ساوزاوے وا داخل بوس',
'resetpass_forbidden' => 'تتے پاسورڈو چینج کوریکو اجازت نیکی',
'resetpass-no-info' => 'ھیہ صفحا براہِ راست رسائیو بچے تہ داخلِ نوشتہ بیک ضروری شیر.',
'resetpass-submit-loggedin' => 'پاسورڈو تبدیلی',
'resetpass-submit-cancel' => 'کھینسل',
'resetpass-wrong-oldpass' => 'عارضی یا موجودہ پاسورڈ ناقص شیر.
تو تان پاسورڈو کامیابیو سورا تبدیل کوری آسوس  یا تو نوغ عارضی پاسورڈو بچے درخواست کوری آسوس.',
'resetpass-temp-password' => 'عارضی پاسورڈ:',

# Special:PasswordReset
'passwordreset' => 'پاسورڈو ری سیٹ کورے',
'passwordreset-username' => 'ممبارو نم',

# Special:ChangeEmail
'changeemail-none' => '(نو)',
'changeemail-cancel' => 'کھینسل',

# Edit page toolbar
'bold_sample' => 'بوسک متن',
'bold_tip' => 'بولڈ ٹیکسٹ',
'italic_sample' => 'کولی/اٹالک نیویشیرو',
'italic_tip' => 'کولی نیویشیرو',
'link_sample' => 'ربطو عنوان',
'link_tip' => 'اندرینو لنک',
'extlink_sample' => 'http://groups.yahoo.com/group/khowaracademy ربطو عنوان',
'extlink_tip' => 'بیریو ربطو (یاد لکھے  http:// prefix)',
'headline_sample' => 'شہ سرخی',
'headline_tip' => 'شہ سرخی درجہ دوم',
'nowiki_sample' => 'غیرشکلبندشدہ متنو ھیارا درج کورور',
'nowiki_tip' => 'ویکی شکلبندی نظرانداز کورے',
'image_tip' => 'پیوستہ مسل',
'media_tip' => 'مسلو لنک',
'sig_tip' => 'تہ دستخط بمع مہرِ وخت',
'hr_tip' => 'تھروسکی لکیر (زیادہ استعمال مو کورے)',

# Edit pages
'summary' => 'خلاصہ:',
'subject' => 'مضمون/شہ سرخی:',
'minoredit' => 'معمولی ترمیم',
'watchthis' => 'ھیہ صفحو لوڑے',
'savearticle' => 'محفوظ',
'preview' => 'نمائش',
'showpreview' => 'نمائش',
'showlivepreview' => 'براہِ راست پیش منظر',
'showdiff' => 'تبدیلیان پشاوے',
'anoneditwarning' => 'تو{{SITENAME}} داخل نو بیتی اسوس لہذا تہIP پتہ ھیہ صفحو تاریخچہ ء ترمیما محفوظ بوی',
'missingcommenttext' => 'براہِ کرم! تبصرہ موڑا درج کورے.',
'missingcommentheader' => "'''خبردار:''' تو ھیہ تبصرو بچے عنوان یا شہ سرخی مہیّا نو آرو.
اگر تو محفوظو بٹنو کہ دوبارہ کلک آرو تھے تہ تبصرہ بغیر عنوانا محفوظ بوی.",
'summary-preview' => 'نمائش خلاصہ:',
'subject-preview' => 'عنوان/شہ سرخیو پیش منظر:',
'blockedtitle' => 'صارفو بلاک کورونو بیتی شیر',
'blockednoreason' => 'کیہ وجہ دیونو نو ھوی',
'whitelistedittext' => 'ترمیم کوریکو بچے $1 ضروری شیر.',
'nosuchsectiontitle' => 'قطعہ ملاو نو ھوی',
'loginreqtitle' => 'داخلہ / اندراج لازم',
'loginreqlink' => 'داخلہ',
'loginreqpagetext' => 'خور صفحاتن لوڑیکو بچے تہ $1 ضروری شیر.',
'accmailtitle' => 'کلمہ شناخت(پاسورڈ) انځینو ھوی',
'newarticle' => '(نوغ)',
'newarticletext' => "↓تو ای ھس صفحو ربطو پیرویو کوری اسوس کہ ھسے ھنیسے موجود نیکی.
ھیہ صفحہو تخلیق کوریکو بچے درج ذیل خانا متنو درج کورے (مزید معلوماتو بچے [[{{MediaWiki:Helppage}}|صفحۂ معاونت]] ملاحظہ کورے).
اگر تو ھیا غلطیو سورا کہ گیتی اسوس تھے اچھو صفحا آچی بیکو بچے تان کمپیوٹرا '''back''' بٹنو ٹک کورے.",
'noarticletext' => ' ھیہ صفحہا فی الحال کیہ متن موجود نیکی.
تو دیگر صفحاتا [[Special:Search/{{PAGENAME}}|ھیہ صفحہو عنوانو بچے تلاش کوریکو بوس]]، <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} متعلقہ نوشتہ جات تلاش کوریکو بوس],
یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} تو ھیہ صفحہا ترمیم کوریکو بوس]</span>',
'noarticletext-nopermission' => 'ھیہ صفحہا فی الحال کیہ متن موجود نیکی.
تو دیگر صفحاتا [[Special:Search/{{PAGENAME}}|ھیہ صفحہو عنوانو بچے تلاش کوریکو بوس]]، <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} متعلقہ نوشتہ جات تلاش کوریکو بوس],
یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} تو ھیہ صفحہا ترمیم کوریکو بوس]</span>',
'updated' => '(اپ ڈیٹڈ)',
'note' => "'''نوٹ:'''",
'previewnote' => "'''یاد لاکھے، ھیہ صرفی نمائش شیر، تہ کاردو ترامیم ھنیسے محفوظ کورونو نو بیتی شینی۔'''",
'editing' => 'تو "$1" ترمیم کوروسان۔',
'editingsection' => '$1 قطعو تدوین',
'editingcomment' => 'زیرترمیم $1 (تبصرہ)',
'editconflict' => 'تنازعہ ترمیم:$1',
'yourtext' => 'تہ تحریر',
'storedversion' => 'ذخیرہ شدہ نظرثانی',
'yourdiff' => 'تضادات',
'templatesused' => 'ھیہ صفحا استعمال باک  {{PLURAL:$1|سانچہ|سانچے}}:',
'templatesusedpreview' => ' ھیہ پیش منظرا مستعمل {{PLURAL:$1|سانچہ|سانچے}}:',
'template-protected' => '(محفوظ شدہ)',
'template-semiprotected' => '(نیم محفوظ)',
'hiddencategories' => 'ھیہ صفحہ {{PLURAL:$1|1 کھوشت زمرے|$1 کھوشت زمرہ جات}}ا شامل شیر:',
'permissionserrorstext-withaction' => 'درج ذیل {{PLURAL:$1|وجہ|وجوہاتن}} پرنیکا تاتے $2 کوریکو اجازت نیکی:',
'recreate-moveddeleted-warn' => "↓''' خبردار: تو ای گزشتہ حذف شدہ صفحو دوبارہ تخلیق کوروسان. '''

تاتے جم پتہ کہ ھیہ صفحو تدوینو جاری لاکھک موزوں نو .
صفحو نوشتۂ حذف شدگی و منتقلی ھیارا تہ سہولتو خاطرا دیونو بویان:",
'moveddeleted-notice' => 'ھیہ ای حذف شدہ صفحہ شیر.
صفحو نوشتۂ حذف شدگی و منتقلی ذیلا بطورِ حوالہ دیونو بویان.',

# Content models
'content-model-javascript' => 'جاوا اسکرپٹ',

# Parser/template warnings
'post-expand-template-inclusion-warning' => "'''خبردار:''' سانچو سایز بو لوٹ شیر.
بعضی سانچہ شامل نو بونی.",
'post-expand-template-inclusion-category' => 'ھش صفحات کہ ھتیرا ٹمپلیٹ یعنی سانچو ناپ لوٹ بیتی شیر۔',
'post-expand-template-argument-warning' => "'''خبردار:''' ھیہ صفحا ای سانچہ(ٹمپلیٹ) مشقولگی دیونو بیتی شیر وا ھمو سایز بولوٹ شیر۔
ھمی لوان نیزونو بیتی شیر",
'post-expand-template-argument-category' => 'ھش صفحات کہ ھتیرا بوغینو بیرو سانچان یعنی(ٹمپلیٹان) لو شینی۔',

# History pages
'viewpagelogs' => 'ھیہ صفحہو بچے نوشتہ جاتن لوڑے',
'currentrev-asof' => 'حالیہ نظرثانی بمطابق $1',
'revisionasof' => 'تـجدید بـمطابق $1',
'revision-info' => '$2 $1 ھموش نیویشیتای',
'previousrevision' => '←پرانو تدوین',
'nextrevision' => '→پروشٹیو اعادہ',
'currentrevisionlink' => 'حالیہ نظرثانی',
'cur' => 'رائج',
'next' => 'پروشٹیو',
'last' => 'سابقہ',
'histlegend' => "انتخاب: مختلف نسخان موازنہ کوریکو بچے ، پیامی خانان نشان زد کوری موڑا دیرو بٹنا کلک کورے۔

'''علامات:'''

(رائج) = موجودہ متنو ساری اخـتلاف، (سابقہ) = گزشتہ متنو ساری اختلاف ، م = معمولی ترمیم۔",
'history-fieldset-title' => 'تاریخو لوڑے',
'history-show-deleted' => 'صرفی حذف شدہ',
'histfirst' => 'قدیم ترین',
'histlast' => 'تازہ ترین',
'historyempty' => '(خالی)',

# Revision feed
'history-feed-item-nocomment' => '$1 تا $2',

# Revision deletion
'rev-delundel' => 'پشاوے/کھوشتاوے',
'rev-showdeleted' => 'پشاوے',
'revdelete-radio-set' => 'Yes/دی',
'revdelete-radio-unset' => 'نو',
'revdel-restore' => 'ظاہریتو تبدیل کورے',
'revdel-restore-deleted' => 'حذف شدہ رویژنز',
'revdel-restore-visible' => 'ویزیبل رویژنز',

# History merging
'mergehistory-revisionrow' => '$1 ($2) $3 . . $4 $5 $6',

# Merge log
'revertmerge' => 'غیر ضم',

# Diffs
'history-title' => 'تاریخچہ "$1"',
'lineno' => 'لکیر $1:',
'compareselectedversions' => 'منتخب متـنو موازنہ',
'editundo' => 'استرجع',
'diff-multi' => '({{PLURAL:$1|One intermediate revision|$1 intermediate revisions}} by {{PLURAL:$2|one user|$2 users}} not shown)',

# Search results
'searchresults' => 'تلاشو نتیجہ',
'searchresults-title' => 'نتائجِ تلاش برائے "$1"',
'searchresulttext' => 'ویکیپیڈیا تلاشو باریا مزید معلوماتو بچے، ویکیپیڈیا تلاشو صفحہو لوڑے۔{{SITENAME}}, [[{{MediaWiki:Helppage}}|{{int:help}}]].
{{SITENAME}}, [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle' => 'تہ تلاش برائے \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|"$1" شروع باک تمام صفحات]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|"$1" مربوط تمام صفحات]])',
'searchsubtitleinvalid' => "تہ تلاش براۓ '''$1'''",
'notitlematches' => 'کیہ دی مماثل عنوان صفحہ ملاو نو ھوی',
'notextmatches' => 'ھیہ عنوانو سورا کیہ دی صفحہ موجود نیکی',
'prevn' => 'آچھو{{PLURAL:$1|$1}}',
'nextn' => 'پروشٹیو{{PLURAL:$1|$1}}',
'prevn-title' => 'سابقہ $1 {{PLURAL:$1|نتیچہ|نتیجہ}}',
'nextn-title' => 'سابقہ $1 {{PLURAL:$1|نتیچہ|نتیجہ}}',
'shown-title' => 'فی صفحہ $1 {{PLURAL:$1|نتیجہ|نتائج}} پشاوے',
'viewprevnext' => 'لوڑے($1 {{int:pipe-separator}} $2) ($3)۔',
'searchmenu-exists' => "'''ھیہ کھوار ویکیپیڈیا \"[[:\$1]]\" نامی ای صفحہ موجود شیر'''",
'searchmenu-new' => "↓'''ھیہ کھوار ویکیپیڈیا صفحہ \"[[:\$1]]\" تخلیق کورے!'''",
'searchprofile-articles' => 'مشمولاتی صفحات',
'searchprofile-project' => 'مدد اوچے منصوبو صفحات',
'searchprofile-images' => 'ملٹی میڈیا',
'searchprofile-everything' => 'سف اشناری',
'searchprofile-advanced' => 'ایڈوانس',
'searchprofile-articles-tooltip' => '$1 ھیہ صفحا تلاش',
'searchprofile-project-tooltip' => '$1 ھیارا تلاش',
'searchprofile-images-tooltip' => 'تلاش برائے فایل',
'searchprofile-everything-tooltip' => 'ہر ژاغا تلاش کورے',
'searchprofile-advanced-tooltip' => 'کسٹم نیم اسپیسا تلاش کورے',
'search-result-size' => '$1 ({{PLURAL:$2|1 لوظ|$2 الفاظ}})',
'search-result-category-size' => '{{PLURAL:$1|1 رُکن|$1 اراکین}} ({{PLURAL:$2|1 ذیلی زمرہ|$2 ذیلی زمرہ جات}}, {{PLURAL:$3|1 ملف|$3 ملفات}})',
'search-redirect' => '(رجوع مکرر $1)',
'search-section' => '(حصہ $1)',
'search-suggest' => 'تہ مطلب ھیہ تھے نو اوشوی: $1',
'search-interwiki-caption' => 'ملگیری منصوبہ',
'search-interwiki-default' => '$1 نتائج:',
'search-interwiki-more' => '(مزید)',
'searchrelated' => 'متعلقہ',
'searchall' => 'کھل',
'showingresultsheader' => "{{PLURAL:$5|نتیجہ'''$1''' of '''$3'''|نتیجہ'''$1 - $2''' of '''$3'''}} بچے'''$4'''",
'nonefound' => "'''یاددہانی''': عموماً صرف ای کما نامان تلاش کورونو بونیان۔
تمام مواد (بشمول تبادلۂ خیال صفحات، سانچہ جات وغیران) تلاش کوریکو بچے تان استفساراری پروشٹی ''all:'' لیگاوے، یا تان پسندو نامو بطور سابقہ استعمال کورے",
'search-nonefound' => 'استفسارو مطابقا نتائج ملاو نو ھونی.',
'powersearch' => 'ایڈوانس تلاش',
'powersearch-legend' => 'ایڈوانس سرچ',
'powersearch-ns' => 'جائے ناما تلاش:',
'powersearch-redir' => 'فہرستِ رجوع مکرر',
'powersearch-field' => 'تلاش برائے',
'powersearch-toggleall' => 'سف',

# Preferences page
'preferences' => 'ترجیحات',
'mypreferences' => 'مہ ترجیہات',
'skin-preview' => 'نمائش',
'youremail' => 'بشلی کغاز',
'username' => 'ممبارو نم',
'uid' => 'ممبارو لمبار:',
'prefs-memberingroups' => '{{PLURAL:$1|گروہ|گروہاں}} رُکن:',
'prefs-registration-date-time' => '$1',
'yourrealname' => '* اصلی نم',
'yournick' => 'دسخط',
'badsig' => "ناقص خام دسخط.
HTML tags لوڑے.',",
'badsiglength' => 'تہ دسخط کافی درونگار شیر.
ھیہ $1 {{PLURAL:$1|حرف|حروفاری}} زیات نو بیلک.',
'prefs-help-email' => 'برقی ڈاکو پتہ اختیاری شیر لیکن ھیہ ھتے وختہ مفید ثابت بوی کیاوتکی تو تان پاسورڈو کی روخڅیتاو',
'prefs-help-email-others' => 'تو ھمو دی منتخب کوریکو بوس  کہ خور صارفین تہ تبادلۂ خیالو صفحا ای ربطو ذریعا تتے بشلی کغاز یعنی برقی ڈاک انځینی.
کیاوتکہ دیگر صارفین تہ سوم رابطہ  کورونیان تھے تہ برقی ڈاکو پتہ افشا کورونو نو بوی',

# Groups
'group-sysop' => 'کھوار ویکیپیڈیو منتظمین',

'grouppage-sysop' => '{{ns:project}}:کھوار ویکیپیڈیو منتظمین',

# Rights
'right-movefile' => 'منتقل کورے',
'right-upload' => 'فائل انځاوے',
'right-delete' => 'صفحان ضائع کورے',

# Special:Log/newusers
'newuserlogpage' => 'نوشتۂ آمد صارف',

# User rights log
'rightslog' => 'یوزروت مختص شدہ حقوق',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'ھیہ صفحا ایڈیٹنگ کورے',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|تبدیلی|تبدیلیاں}}',
'recentchanges' => 'حالیہ تبدیلی',
'recentchanges-legend' => 'حالیہ تبدیلیان اختیارات',
'recentchanges-summary' => 'ھیہ صفحا کھوار ویکیپیڈیا باک تازہ تریں تبدیلیان مشاہدہ کورے',
'recentchanges-feed-description' => 'کھوارا ترجمہ',
'recentchanges-label-newpage' => 'ھیہ ترمیم نوغ صفحہ تخلیق آریر',
'recentchanges-label-minor' => 'ھیہ ای معمولی ترمیم شیر',
'recentchanges-label-bot' => 'ھیہ ایڈیٹو خود کار بوٹو زریعا انجام دیونو ہوی',
'recentchanges-label-unpatrolled' => 'ھیہ ترمیمو ھمونیہ پت مراجعت(Patrolled) کورونو نو بیتی شیر',
'rcnote' => "درج ذیل گزشتہ {{PLURAL:$2|بس|'''$2''' انوسا}} باک {{PLURAL:$1|'''ای''' تبدیلی شیر|آخری '''$1''' تبدیلی شینی}}، $5، $4.",
'rcnotefrom' => "ھیہ موڑا '''$2''' کورونو بیرو تبدیلیان تفصیلات شینی ('''$1''' تبدیلیان پشینو بونیان)۔",
'rclistfrom' => '$1 نوغ تبدیلیاں پشیک شروع کورے',
'rcshowhideminor' => ' معمولی ترامیم $1',
'rcshowhidebots' => 'خودکار صارف $1',
'rcshowhideliu' => 'داخل بیرو صارف $1',
'rcshowhideanons' => 'گمنام صارف $1',
'rcshowhidepatr' => '$1 لوڑونو بیرو لکھائی',
'rcshowhidemine' => 'ذاتی ترامیم $1',
'rclinks' => 'آخری $2 آنوسو بیرو $1 تبدیلیان مشاہدہ کورے<br />$3',
'diff' => 'فرق',
'hist' => 'تاریخچہ',
'hide' => 'مو پشاوے',
'show' => 'ویریغ کورے',
'minoreditletter' => 'م',
'newpageletter' => 'نوغ',
'boteditletter' => 'خودکار',
'rc-enhanced-expand' => 'تفصیلاتن پشاوے (JavaScript ضرورت بوی)',
'rc-enhanced-hide' => 'تفصیلاتن کھوشتاوے',

# Recent changes linked
'recentchangeslinked' => 'متعلقہ تبدیلی',
'recentchangeslinked-toolbox' => 'موقعی تبدیلی',
'recentchangeslinked-title' => 'متعلقہ تبدیلی "$1"',
'recentchangeslinked-summary' => "ھیہ ھتے تبدیلیان لسٹ شیر کہ ھیتان پھوک مدا پروشٹی ساوزینو بیتی شینی وا ھے صفحان سوم جستہ خور کیہ صفحہ چوکی شینی یا کیہ خاص زمرہ جاتو ممبرانن سوم چوکی شینی<br />
ساوزیرو [[Special:Watchlist|موڑا صفحہ]] '''بولڈ''' شینی",
'recentchangeslinked-page' => 'کھوار ویکیپیڈیو منصوبو صفحو لوڑے',
'recentchangeslinked-to' => 'کھولاو بیرو صفحو بجایا ھمو سوم چوکیرو صفحو نوغ تبدیلیان پشاوے',

# Upload
'upload' => 'فائل انځاوے',
'uploadlogpage' => 'نوشتۂ زبراثقال (اپ لوڈ لاگ)',
'filename' => 'فایلو نام',
'filedesc' => 'خلاصہ',
'uploadedimage' => 'زبراثقال (اپ لوڈ) براۓ "[[$1]]"',

'license' => 'لایسنس',
'license-header' => 'لایسنسنگ',

# File description page
'file-anchor-link' => 'فایل',
'filehist' => 'مسلو تاریخ',
'filehist-help' => 'ھیہ لوڑیکو بچے  کہ کیہ خاص وختہ فایل کیہ قسمہ ظاہر باو اوشتای ھتے  تاریخ یا وختہ طق(کلک) کورے',
'filehist-revert' => 'آچی',
'filehist-current' => 'حالیہ',
'filehist-datetime' => 'تاریخ/وخت',
'filehist-thumb' => 'اظفورہ',
'filehist-thumbtext' => '$1 صارفو څیق ھوٹو',
'filehist-user' => 'صارف',
'filehist-dimensions' => 'ابعاد',
'filehist-comment' => 'تبصرہ',
'imagelinks' => 'مسلو روابط',
'linkstoimage' => 'ھیہ مسلو سوم درج ذیل {{PLURAL:$1|صفحہ مربوط شیر|$1 صفحات مربوط شینی}}',
'nolinkstoimage' => 'ھیہ کھوار ویکیپیڈیا ھش کیہ صفحات نیکی کہ ھتیت ھیہ مسل (فائلو) متعلقہ شینی',
'sharedupload-desc-here' => 'ھیہ فائل $1 موژاری شیر وا ھیہ خور پرجیکٹہ استعمال بویان۔
مزید معلومات ھمو [$2 فائل مشقولگی صفحہا]  دیونو بیتی شیر',
'uploadnewversion-linktext' => 'ھیہ مسلو نوغ ورژنو اپلوڈ کورے',

# Random page
'randompage' => 'بےترتیب صفحہ',

# Statistics
'statistics' => 'اعداد و شمار',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|بایٹ|بایٹس}}',
'nmembers' => '$1 {{PLURAL:$1|ممبار|ممباران}}',
'lonelypages' => 'څھوعو صفحات',
'unusedcategories' => 'غیر استعمال شدہ زمرہ جات',
'unusedimages' => 'غیر استعمال شدہ فائل',
'popularpages' => 'مقبول صفحات',
'wantedcategories' => 'طلب شدہ زمرہ جات',
'wantedpages' => 'درخواست شدہ مضامین',
'wantedfiles' => 'درخواست شدہ مضامین',
'wantedtemplates' => 'درخواست شدہ سانچہ',
'mostlinked' => 'سفو ساری زیات ربط(لنک) والا مضمون',
'mostlinkedcategories' => 'سفو ساری زیات ربط(لنک) والا زمرہ جات',
'mostlinkedtemplates' => 'سفو ساری زیات ربط(لنک) والا سانچہ',
'mostcategories' => 'سفو ساری زیات زمرہ جات والا مضمون',
'mostimages' => 'سفو ساری زیادہ استعمال کاردو ھوٹو',
'mostrevisions' => 'زیادہ تجدید نظر کورونو بیرو صفحات',
'prefixindex' => 'کھلی صفحات پریفکسان سوم جستہ',
'shortpages' => 'څیق صفحات',
'longpages' => 'درونگار ترین صفحات',
'deadendpages' => 'بیردو صفحات',
'protectedpages' => 'محفوظ شدہ صفحہ',
'protectedtitles' => 'محفوظ شدہ صفحہ',
'listusers' => 'فہرست ارکان',
'usercreated' => '
{{GENDER:$3|تخلیق شدہ}}  بتاریخ $1 بوقت $2',
'newpages' => 'نوغ صفحات',
'newpages-username' => 'اسمِ رکنیت',
'move' => 'منتقل',
'movethispage' => 'ھیہ صفحو خور ژاغا  منتقل کورے',
'pager-newer-n' => '{{PLURAL:$1|نوغ1|نوغ $1}}',
'pager-older-n' => '{{PLURAL:$1|قدیم1|قدیم ترین $1}}',

# Book sources
'booksources' => 'کتابی وسائل',
'booksources-search-legend' => 'کتابی وسایلان تلاش',
'booksources-go' => 'Go/بوغے',

# Special:Log
'specialloguserlabel' => 'یوزر',
'speciallogtitlelabel' => 'عنوان:',
'log' => 'نوشتہ جات',

# Special:AllPages
'allpages' => 'سف صفحات',
'alphaindexline' => '$1 تا $2',
'prevpage' => 'آچھو صفحہ ($1)',
'allpagesfrom' => 'مطلوبہ حرفاری شروع باک صفحاتن نمائش:',
'allpagesto' => 'مطلوبہ حرفاری ختم باک صفحاتن نمائش:',
'allarticles' => 'تمام مقالات',
'allpagesprev' => 'آچھو',
'allpagesnext' => 'پروشٹیو',
'allpagessubmit' => 'بوغے لا',

# Special:Categories
'categories' => 'زمرہ جات',

# Special:DeletedContributions
'sp-deletedcontributions-contribs' => 'حصہ',

# Special:LinkSearch
'linksearch' => 'بیریو لنک',
'linksearch-ns' => 'نامو ژاغہ:',
'linksearch-ok' => 'Search/تلاش',
'linksearch-line' => '$1 مربوط شیر $2 ری',

# Special:ListGroupRights
'listgrouprights-members' => 'ممبارانن فھرست',

# Email user
'emailuser' => 'ممباروت بشلی کغاز انڅاوے',

# Watchlist
'watchlist' => 'مہ واچ لسٹ',
'mywatchlist' => 'مہ زیرنظرفہرست',
'watchlistfor2' => 'براۓ $1 ($2)',
'removedwatchtext' => 'ھیہ صفحہ "[[:$1]]" خارج کورونو ھوی[[Special:Watchlist|تہ زیر نظر فہرستاری]].',
'watch' => 'زیرنظر',
'watchthispage' => 'ھیہ صفحو تان نظرا لاکھے',
'unwatch' => 'زیرنظرمنسوخ',
'watchlist-details' => ' تہ زیرِنظرفہرستا {{PLURAL:$1|$1 صفحہ شیر|$1 صفحات شینی}}، ھیارا تبادلۂ خیالو صفحاتن تعداد شامل نیکی.',
'wlshowlast' => 'پشاوے آخری $1 گھنٹو $2 آنوسو $3',
'watchlist-options' => 'واچ لسٹ آپشن',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'زیر نظر',
'unwatching' => 'منسوخ',

# Delete
'deletepage' => 'صفحہو ضائع کورے',
'confirmdeletetext' => 'تو ھیہ صفحو ھمو سوم ملحقہ تاریخچو سوم جستہ حذف کوریکو ارادہ کوری آسوس ۔ براۓ مہربانی تصدیق کورے کہ تو ھیہ عملو نتائجان ساری بخوبی آگاہ آسوس، وا ھیہ یقینو دی کورے کہ تو ھش [[{{MediaWiki:Policy-url}}|ویکیپیڈیو حکمت عملیو]] دائرا حال بتی کوروسان۔',
'actioncomplete' => 'اقدام تکمیلوتے تورتای',
'actionfailed' => 'تہ ایکشن ناکام ہوی',
'deletedtext' => '"$1" حذف کورونو بیتی شیر ۔
حالیہ حذف شدگیو تاریخ نامو بچے  $2  لوڑے',
'dellogpage' => 'نوشتۂ حذف شدگی',
'deletecomment' => 'وجہ',
'deleteotherreason' => 'جوو/اِضافی وجہ',
'deletereasonotherlist' => 'جوو وجہ',

# Rollback
'rollbacklink' => 'آچی سابقہ حالتہ',

# Protect
'protectlogpage' => 'نوشتۂ محفوظ شدگی',
'protectedarticle' => '"[[$1]]" محفوظ کورونو ھوی',
'modifiedarticleprotection' => 'تبدیل کاردو پروٹیکشن لیول "[[$1]]"',
'protectcomment' => 'وجہ:',
'protectexpiry' => 'ختم بویان:',
'protect_expiry_invalid' => 'Expiry ٹیم غلط شیر.',
'protect_expiry_old' => 'ایکسپایری ٹیم مسقبلا',
'protect-text' => "You may view and change the protection level here for the page '''$1'''.
تو ھیارا پروٹیکشن لیولو لوڑیکو اوچے چینج کوریکو بوس '''$1'''.",
'protect-default' => 'تمام صارفینانتے اجازت دیت',
'protect-fallback' => 'ضرورت شیر"$1" اجازتو',
'protect-level-autoconfirmed' => 'نوغ اوچے غیر رجسٹیر شدہ یوزران بلاک کورے',
'protect-level-sysop' => 'صرفی منتظمینان بچے',
'protect-expiring' => 'ختم بویان $1 (UTC)',
'protect-cantedit' => 'تو ھیہ صفحو پروٹیکشن لیولو چینج کوریکو نوبوس، کوریکو کہ تاتے ھش کوریکو اجازت نیکی',
'restriction-type' => 'اجازت',
'restriction-level' => 'ممنوغ لیول',

# Undelete
'undelete' => 'ضائع کاردو صفحاتن لوڑے',
'undeletelink' => 'لوڑے/بحال کورے',
'undeleteviewlink' => 'لوڑے',

# Namespace form on various pages
'namespace' => 'نامو ژاغہ:',
'invert' => 'انتخاب بالعکس',
'blanknamespace' => '(مرکز)',

# Contributions
'contributions' => ' $1 صارفو حصہ',
'contributions-title' => '$1 صارفو حصہ',
'mycontris' => 'مہ حصہ',
'contribsub2' => 'براۓ $1 ($2)',
'uctop' => '(ٹیکہ)',
'month' => 'مس (وا ھیغاری پروشٹی):',
'year' => 'سال (وا ھیغاری پروشٹی):',

'sp-contributions-newbies' => 'صرفی نوغ اکاونٹو مضمونن پشاوے',
'sp-contributions-newbies-sub' => 'نوغ اکاونٹو بچے',
'sp-contributions-blocklog' => 'پاوبندی لیگیکو چٹ',
'sp-contributions-uploads' => 'اپلوڈ کاردو فایل',
'sp-contributions-logs' => 'لاگز',
'sp-contributions-talk' => 'تبادلہ خیال',
'sp-contributions-search' => 'تان نیویشیرو مضمونن تلاش کورے',
'sp-contributions-username' => 'آئی.پی پتہ یا اسمِ صارف:',
'sp-contributions-toponly' => 'صرف حالیہ ترین نظرثانی ترمیماتن پشاؤے',
'sp-contributions-submit' => 'Search/تلاش',

# What links here
'whatlinkshere' => 'ھیارا کیہ کیہ لنک شینی',
'whatlinkshere-title' => 'لنک شدہ صفحات "$1"',
'whatlinkshere-page' => ' صفحہ:',
'linkshere' => " '''[[:$1]]''' درج ذیل صفحات لنک کوری شینی:",
'nolinkshere' => "'''[[:$1]]''' کیہ روابط نیکی",
'isredirect' => 'خور ژاغا آلدو صفحہ',
'istemplate' => 'ٹرانسکلوژن',
'isimage' => 'ھوٹوان لنک',
'whatlinkshere-prev' => '{{Plural:$1|سابقہ|سابقہ $1}}',
'whatlinkshere-next' => '{{PLURAL:$1|پروشٹیو|پروشٹیو$1}}',
'whatlinkshere-links' => '← لنکس',
'whatlinkshere-hideredirs' => '$1 رجوع مکرر',
'whatlinkshere-hidetrans' => 'ٹرانسکلوژن $1',
'whatlinkshere-hidelinks' => '$1 لنکس',
'whatlinkshere-hideimages' => 'ھوٹوان لنک $1',
'whatlinkshere-filters' => 'فلٹر',

# Block/unblock
'blockip' => 'داخلہ ممنوع براۓ صارف',
'ipboptions' => '2 گھنٹہ:2 hours,1 آنوس:1 day,3 بس:3 days,1 ہفتہ:1 week,2 ہفتہ:2 weeks,1 مس:1 month,3 مس:3 months,6 مس:6 months,1 سال:1 year,لامحدود:infinite',
'ipblocklist' => 'داخلہ ممنوع براۓ صارف',
'blocklink' => 'پاوبندی لیگاوے',
'unblocklink' => 'پاوبندی ختم',
'change-blocklink' => 'پاوبندیا تبدیلی',
'contribslink' => 'حصہ داری',
'blocklogpage' => 'نوشتۂ پاوبندی',
'blocklogentry' => 'بلاک[[$1]] وختہ پت $2 $3',
'unblocklogentry' => 'بلاک نو کاردو $1',
'block-log-flags-nocreate' => 'کھاتہ کھولاو کوریکو سورا پاوپندی شیر',

# Move page
'movearticle' => 'مـنـتـقـل کـورے',
'newtitle' => 'نوغ عنوان',
'move-watch' => 'صفحہ زیر نظر',
'movepagebtn' => 'منتقل',
'pagemovedsub' => 'انتقال کامیاب',
'movepage-moved' => '\'\'\'"$1" ھیہ ووشکی منتقل کورونو ھوی "$2"\'\'\'',
'articleexists' => 'ھیہ عنوانو سورا کیہ صفحہ پروشٹیاری موجودشیر یا تہ درخواست کاردو  نام مستعمل نیکی براۓ مہربانی خور نامو منتخب کورے۔',
'movedto' => 'آلونو ھوی',
'movelogpage' => 'نوشتۂ منتقلی',
'movereason' => 'واجھہ',
'revertmove' => 'رجوغ',

# Export
'export' => 'برآمد صفحات',

# Namespace 8 related
'allmessagesname' => 'نم',
'allmessagesdefault' => 'طے شدہ متن',

# Thumbnails
'thumbnail-more' => 'فراخ کورے',
'thumbnail_error' => '$1 څیق سایزو ھوٹو ساوزیکا مسئلہ',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'تہ صارفی صفحہ',
'tooltip-pt-mytalk' => 'تہ صفحۂ مشقولگی',
'tooltip-pt-preferences' => ' تہ ترجیحات',
'tooltip-pt-watchlist' => 'ھتے صفحاتن فہرست کہ ھتیتان تبدیلی تہ زیرِنظر شینی',
'tooltip-pt-mycontris' => 'تہ کاردو کورمان فہرست',
'tooltip-pt-login' => 'تہ بچے داخلِ نوشتہ بیک جم شیر، لیکن ھیہ ضروری نو',
'tooltip-pt-logout' => 'خارج بوس',
'tooltip-ca-talk' => 'مضمونو بارا تبادلۂ خیال',
'tooltip-ca-edit' => 'تو ھیہ صفحہا ترمیم کوریکو بوس
برائے مہربانی! تان ترمیماتن محفوظ کوریکار پروشٹی  نمائشو بٹنا کلک کورے',
'tooltip-ca-addsection' => 'نوغ قطعہ شروع کورے',
'tooltip-ca-viewsource' => 'ھیہ ای محفوظ شدہ صفحہ شیر
تو صرف ھمو مآخذو لوڑیکو بوس',
'tooltip-ca-history' => 'ھیہ صفحو سابقہ نظرثانی',
'tooltip-ca-protect' => 'ھیہ صفحہو محفوظ کورے',
'tooltip-ca-delete' => 'ھیہ صفحہو بوغاوے',
'tooltip-ca-move' => 'ھیہ صفحو منتقل کورے',
'tooltip-ca-watch' => 'ھیہ صفحہو تان زیرِنظرفہرستہ شامل کورے',
'tooltip-ca-unwatch' => 'ھیہ صفحہو تان زیرِنظرفہرستاری نیزے',
'tooltip-search' => 'تلاش {{SITENAME}}',
'tooltip-search-go' => 'اگر بالکل ھیہ نامو سورا صفحہ کہ موجود شیر تھے ھتے صفحہا بوغے',
'tooltip-search-fulltext' => 'ھیہ متنو بچے صفحاتن تلاش کورے',
'tooltip-p-logo' => 'سرورقا بوغے',
'tooltip-n-mainpage' => 'اصلی صفحہا بوغے',
'tooltip-n-mainpage-description' => 'اصلی صفحہ',
'tooltip-n-portal' => 'کھوار ویکیپیڈیو منصوبو متعلقہ، تو کیاغ کوریکو بوس، اشناریان کورا تلاش کوریلک',
'tooltip-n-currentevents' => 'حالیہ واقعاتہ بیرو پس منظری معلوماتن لوڑے',
'tooltip-n-recentchanges' => 'کھوار ویکیپیڈیا حالیہ تبدیلیان فہرست',
'tooltip-n-randompage' => 'ای بے ترتیب صفحہ لوڈ کورے',
'tooltip-n-help' => 'تلاش کوریکو ژاغہ',
'tooltip-t-whatlinkshere' => 'ھتے سف ویکی صفحاتن فہرست کہ ھتیتان ھیارا لنک شیر',
'tooltip-t-recentchangeslinked' => 'ھیہ صفحہو سوم مربوط صفحاتہ بیرو حالیہ تبدیلی',
'tooltip-feed-rss' => 'ھیہ صفحو بچے اسس خورد',
'tooltip-feed-atom' => 'ھیہ صفحو بچے آٹوم فیڈ',
'tooltip-t-contributions' => 'نوغ تدوین',
'tooltip-t-emailuser' => 'ھیہ ممباروت بشلی کغاز(ای میل) انڅاوے',
'tooltip-t-upload' => 'اپلوڈ فایل',
'tooltip-t-specialpages' => 'سف خاص صفحاتن فہرست',
'tooltip-t-print' => 'ھیہ صفحو قابل طبع نسخہ',
'tooltip-t-permalink' => 'صفحہعو موجودہ نظرثانیو مستقل لنک',
'tooltip-ca-nstab-main' => 'مضمونو صفحو لوڑے',
'tooltip-ca-nstab-user' => 'ممبارو صفحو لوڑے',
'tooltip-ca-nstab-special' => 'ھیہ ای خاص صفحہ شیر، تو ھیارا ترمیم کوریکو نو بوس',
'tooltip-ca-nstab-project' => 'پروجیکٹو صفحو لوڑے',
'tooltip-ca-nstab-image' => 'مسلو صفحو لوڑے',
'tooltip-ca-nstab-template' => 'سانچو لوڑے',
'tooltip-ca-nstab-category' => 'زمرہ جاتی صفحو لوڑے',
'tooltip-minoredit' => 'ھیہ تدوینو بطورِ معمولی ترمیم نشانزد کورے',
'tooltip-save' => 'تبدیلیان محفوظ کورے',
'tooltip-preview' => 'برائے مہربانی! محفوظ کوریکار پروشٹی تبدیلیان پیشمنظرو لوڑے',
'tooltip-diff' => 'لوڑے کہ تو تان مضمونو متنہ کیہ کیہ تبدیلی آرو',
'tooltip-compareselectedversions' => 'منتخب متـنو موازنہ',
'tooltip-watch' => 'ھیہ صفحہو تان زیرِنظرفہرستہ شامل کورے',
'tooltip-rollback' => '"رول بیک" ای کلکا صفحو واپس سابقہ حالتہ گنی آلوی',
'tooltip-undo' => '"واپس" یا لوظ آچیا کلک کوریکو سوم جستہ تہ صفحہ کچا تہ پشینو بوی ھے سوم جستہ تو واپس کوریکو وجہ نیویشیکو بوس',
'tooltip-summary' => 'ای مختصار سمری ساوزاوے',

# Browsing diffs
'previousdiff' => ' ← پرانو تدوین',
'nextdiff' => 'صفحہو نم:',

# Media information
'file-info-size' => '$1 × $2 پکسلز, فل سایز: $3, MIME ٹایپ: $4',
'file-nohires' => 'ھموغاری لوٹ ریزولیوشن دستیاب نیکی.',
'svg-long-desc' => 'SVG فایل, nominally $1 × $2 پکسلز, فایل سایز: $3',
'show-big-image' => 'لوٹ کوری پشاوے',

# Bad image list
'bad_image_list' => 'شکلبند درج ذیل شیر:

صرف فہرستی عناصرار (* شروع باک لکیر) شامل کورونو بونیان
کیہ لکیرا آویلو ربط کیہ خراب فایلو بیلیک۔
ھتے لکیرا باقی گیاک ربطو مستثنیٰ قرار دیونو بویان، مثلاً صفحات کورا کہ فایل لکیرو موژا گویان۔',

# Metadata
'metadata' => 'میٹا ڈیٹا',
'metadata-help' => 'ھیہ فائلا خور دی معلومات شینی، شاید ھتیت ڈیجیٹل کیمرو یا سکینران زریعا کمپیوٹرو درینو بیتی شینی وا ھیتان زریعا ھمیتان ڈیجیٹل ساوزینو بیتی شیر

اگر فائلو ھمو اصلی حالتہ  تبدیل کہ کورونو ھوی تھے ای کما تفصیلات تبدیل بیرو فائلو باریا موجود نیکی',
'metadata-expand' => 'تفصیلان پشاوے',
'metadata-collapse' => 'درونگار تفصیلان کھوشتاوے',
'metadata-fields' => 'ایگزف میٹاڈیٹا ھیارا دیونو بیرو ھوٹوان صفحا دیونو بونی وا کیاوتکہ میٹاڈیٹا ٹیبل کھولاو ھوی باقی اشناری بائی ڈیفالٹ کھوشت تان بہچونی
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

'exif-dc-date' => 'تاریخ',

# External editor support
'edit-externally' => 'ھیہ مسلو ایڈیٹ کورے',
'edit-externally-help' => '(See the [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] for more information)
(مزید معلوماتو بچے ھیہ لنکہ بوغے [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] )',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'سف',
'namespacesall' => 'تھمامو',
'monthsall' => 'سف',

# action=purge
'confirm_purge_button' => 'OK/ٹھیک شیر',

# Table pager
'table_pager_first' => 'آویلو صفحہ',

# Watchlist editing tools
'watchlisttools-view' => 'موقعی تبدیلیان لوڑے',
'watchlisttools-edit' => 'لوڑے یا واچ لسٹہ ترمیم کورے',
'watchlisttools-raw' => 'نوغ واچ لسٹان ایڈیٹ کورے',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'خبردار:\'\'\' ڈیفالٹ تاڑٰ(نغڑی) "$2" پروشٹیو ڈیفالٹ تاڑا "$1" لیگی شیر۔',

# Special:SpecialPages
'specialpages' => 'اسپیشل صفحہ',

# External image whitelist
'external_image_whitelist' => ' #ھیہ لاینو ھموش تان شیکو لاکے کیچہ کہ ھیہ شیر<pre>
#موڑا ریگولر لوان دیور((صرف ھتیتان کیاغ ھمیتان موژی شینی //) //) 
#بیریو ھوٹوان آر ایلان سوم ھمیتان میچ کورنو بوی
# کیاغ کہ میچ ھونی ھیتان ھوٹوان سوم پشینو بوی بصورت دیگر ھیتان لنک کیاغ کی شینی ھتیتان پشینو بوی
#لاین کیاغ کی شروع بویان  # کومنٹ جوشونو بوی۔
#ھیہ کیس سینسیٹو شیر۔

#لینو سورا ریجیکس فریگمنٹو لاکھے. ھیہ لاینو ھموش تان شیکو لاکے کیچہ کہ ھیہ شیر۔</pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tag]] filter:',
'tag-filter-submit' => 'فلٹر',
'tags-title' => 'Tags/ٹیگز',

# Special:ComparePages
'compare-page1' => 'صفحہ 1',

# New logging system
'rightsnone' => '(نو)',

# Feedback
'feedback-message' => 'پیغام',

# Search suggestions
'searchsuggest-search' => 'Search/تلاش',

);
